@@ -589,7 +589,8 @@ bool Notepad_plus::doReload(BufferID id, bool alert)
 	// many settings such as update status bar, clickable link etc.
 	activateBuffer(id, currentView(), true);
 
-	if (NppParameters::getInstance().getSVP()._isChangeHistoryEnabled)
+	auto svp = NppParameters::getInstance().getSVP();
+	if (svp._isChangeHistoryMarginEnabled || svp._isChangeHistoryIndicatorEnabled)
 		clearChangesHistory();
 
 	return res;
@@ -1792,6 +1793,17 @@ bool Notepad_plus::fileSaveAs(BufferID id, bool isSaveCopy)
 
 	fDlg.setExtIndex(langTypeIndex + 1); // +1 for "All types"
 
+	generic_string localizedTitle;
+	if (isSaveCopy)
+	{
+		localizedTitle = _nativeLangSpeaker.getNativeLangMenuString(IDM_FILE_SAVECOPYAS, L"Save a Copy As", true);
+	}
+	else
+	{
+		localizedTitle = _nativeLangSpeaker.getNativeLangMenuString(IDM_FILE_SAVEAS, L"Save As", true);
+	}
+	fDlg.setTitle(localizedTitle.c_str());
+
 	const generic_string checkboxLabel = _nativeLangSpeaker.getLocalizedStrFromID("file-save-assign-type",
 		TEXT("&Append extension"));
 	fDlg.enableFileTypeCheckbox(checkboxLabel, !defaultAllTypes);
@@ -1875,8 +1887,8 @@ bool Notepad_plus::fileRename(BufferID id)
 		fDlg.setFolder(buf->getFullPathName());
 		fDlg.setDefFileName(buf->getFileName());
 
-		std::wstring title = _nativeLangSpeaker.getLocalizedStrFromID("file-rename-title", L"Rename");
-		fDlg.setTitle(title.c_str());
+		wstring localizedRename = _nativeLangSpeaker.getNativeLangMenuString(IDM_FILE_RENAME, L"Rename", true);
+		fDlg.setTitle(localizedRename.c_str());
 
 		std::wstring fn = fDlg.doSaveDlg();
 
@@ -2011,6 +2023,8 @@ bool Notepad_plus::fileDelete(BufferID id)
 void Notepad_plus::fileOpen()
 {
 	CustomFileDialog fDlg(_pPublicInterface->getHSelf());
+	wstring localizedTitle = _nativeLangSpeaker.getNativeLangMenuString(IDM_FILE_OPEN, L"Open", true);
+	fDlg.setTitle(localizedTitle.c_str());
 	fDlg.setExtFilter(TEXT("All types"), TEXT(".*"));
 
 	setFileOpenSaveDlgFilters(fDlg, true);
@@ -2460,6 +2474,8 @@ bool Notepad_plus::fileLoadSession(const TCHAR *fn)
 			fDlg.setDefExt(ext);
 		}
 		fDlg.setExtFilter(TEXT("All types"), TEXT(".*"));
+		wstring localizedTitle = _nativeLangSpeaker.getNativeLangMenuString(IDM_FILE_LOADSESSION, L"Load Session", true);
+		fDlg.setTitle(localizedTitle.c_str());
 		sessionFileName = fDlg.doOpenSingleFileDlg();
 	}
 	else
@@ -2558,9 +2574,10 @@ const TCHAR * Notepad_plus::fileSaveSession(size_t nbFile, TCHAR ** fileNames)
 	}
 	fDlg.setExtFilter(TEXT("All types"), TEXT(".*"));
 	const bool isCheckboxActive = _pFileBrowser && !_pFileBrowser->isClosed();
-	const generic_string checkboxLabel = _nativeLangSpeaker.getLocalizedStrFromID("session-save-folder-as-workspace",
-		TEXT("Save Folder as Workspace"));
+	const generic_string checkboxLabel = _nativeLangSpeaker.getLocalizedStrFromID("session-save-folder-as-workspace", L"Save Folder as Workspace");
 	fDlg.setCheckbox(checkboxLabel.c_str(), isCheckboxActive);
+	wstring localizedTitle = _nativeLangSpeaker.getNativeLangMenuString(IDM_FILE_SAVESESSION, L"Save Session", true);
+	fDlg.setTitle(localizedTitle.c_str());
 	generic_string sessionFileName = fDlg.doSaveDlg();
 
 	if (!sessionFileName.empty())
