@@ -884,75 +884,44 @@ void FileBrowser::getDirectoryStructure(const TCHAR *dir, const std::vector<gene
 	dirFilter += TEXT("*.*");
 	WIN32_FIND_DATA foundData;
 
-	HANDLE hFile = ::FindFirstFile(dirFilter.c_str(), &foundData);
-
-	if (hFile != INVALID_HANDLE_VALUE)
+	HANDLE hFindFile = ::FindFirstFile(dirFilter.c_str(), &foundData);
+	if (hFindFile != INVALID_HANDLE_VALUE)
 	{
-
-		if (foundData.dwFileAttributes & FILE_ATTRIBUTE_DIRECTORY)
+		do
 		{
-			if (!isInHiddenDir && (foundData.dwFileAttributes & FILE_ATTRIBUTE_HIDDEN))
+			if (foundData.dwFileAttributes & FILE_ATTRIBUTE_DIRECTORY)
 			{
-				// do nothing
-			}
-			else if (isRecursive)
-			{
-				if ((OrdinalIgnoreCaseCompareStrings(foundData.cFileName, TEXT(".")) != 0) && (OrdinalIgnoreCaseCompareStrings(foundData.cFileName, TEXT("..")) != 0))
+				if (!isInHiddenDir && (foundData.dwFileAttributes & FILE_ATTRIBUTE_HIDDEN))
 				{
-					generic_string pathDir(dir);
-					if (pathDir[pathDir.length() - 1] != '\\')
+					// do nothing
+				}
+				else if (isRecursive)
+				{
+					if ((OrdinalIgnoreCaseCompareStrings(foundData.cFileName, TEXT(".")) != 0) && 
+						(OrdinalIgnoreCaseCompareStrings(foundData.cFileName, TEXT("..")) != 0))
+					{
+						generic_string pathDir(dir);
+						if (pathDir[pathDir.length() - 1] != '\\')
+							pathDir += TEXT("\\");
+						pathDir += foundData.cFileName;
 						pathDir += TEXT("\\");
-					pathDir += foundData.cFileName;
-					pathDir += TEXT("\\");
 
-					FolderInfo subDirectoryStructure(foundData.cFileName, &directoryStructure);
-					getDirectoryStructure(pathDir.c_str(), patterns, subDirectoryStructure, isRecursive, isInHiddenDir);
-					directoryStructure.addSubFolder(subDirectoryStructure);
+						FolderInfo subDirectoryStructure(foundData.cFileName, &directoryStructure);
+						getDirectoryStructure(pathDir.c_str(), patterns, subDirectoryStructure, isRecursive, isInHiddenDir);
+						directoryStructure.addSubFolder(subDirectoryStructure);
+					}
 				}
 			}
-		}
-		else
-		{
-			if (matchInList(foundData.cFileName, patterns))
+			else
 			{
-				directoryStructure.addFile(foundData.cFileName);
-			}
-		}
-	}
-
-	while (::FindNextFile(hFile, &foundData))
-	{
-		if (foundData.dwFileAttributes & FILE_ATTRIBUTE_DIRECTORY)
-		{
-			if (!isInHiddenDir && (foundData.dwFileAttributes & FILE_ATTRIBUTE_HIDDEN))
-			{
-				// do nothing
-			}
-			else if (isRecursive)
-			{
-				if ((OrdinalIgnoreCaseCompareStrings(foundData.cFileName, TEXT(".")) != 0) && (OrdinalIgnoreCaseCompareStrings(foundData.cFileName, TEXT("..")) != 0))
+				if (matchInList(foundData.cFileName, patterns))
 				{
-					generic_string pathDir(dir);
-					if (pathDir[pathDir.length() - 1] != '\\')
-						pathDir += TEXT("\\");
-					pathDir += foundData.cFileName;
-					pathDir += TEXT("\\");
-
-					FolderInfo subDirectoryStructure(foundData.cFileName, &directoryStructure);
-					getDirectoryStructure(pathDir.c_str(), patterns, subDirectoryStructure, isRecursive, isInHiddenDir);
-					directoryStructure.addSubFolder(subDirectoryStructure);
+					directoryStructure.addFile(foundData.cFileName);
 				}
 			}
-		}
-		else
-		{
-			if (matchInList(foundData.cFileName, patterns))
-			{
-				directoryStructure.addFile(foundData.cFileName);
-			}
-		}
+		} while (::FindNextFile(hFindFile, &foundData));
+		::FindClose(hFindFile);
 	}
-	::FindClose(hFile);
 }
 
 void FileBrowser::addRootFolder(generic_string rootFolderPath)
